import setuptools

setuptools.setup(
    name="hypernova_jinja2_directive",
    version="0.1.0",
    author="marconi1992",
    author_email="felipegaiacharly@gmail.com",
    description="Hypernova Directive jinja2",
    url="https://github.com/ara-framework/hypernova-jinja2-directive",
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 2",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)